capture log close
log using mco18-lrm-canada-wages, replace text
version 14.2
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  Modeling Categorical Outcomes - 2018
//  LRM with nonlinearity 

local pgm mco18-lrm-canada-wages
local dte 2018-04-02
local who Scott Long
local tag "`pgm'.do `who' `dte'"

global plotfmt emf 
if "`c(os)'"!="Windows" global plotfmt pdf

//  #0 setup

use slid-ontario01, clear
codebook, compact

//  options for graphs

local labgrid "labsize(*1.1) glwid(*.7) glcol(black*.3) grid gmin gmax"
local labnogrid "labsize(*1.1) nogrid"
local plt1options ///
    "lcol(blue*1.) lpat(solid) msym(O)  msiz(*1.) mcol(blue*1.)"
local plt2options ///
    "lcol(red*1.) lpat(dash) msym(S)  msiz(*.9) mcol(red*1.)"
local pltDCoptions ///
    "lcol(green*1.) lpat(solid) msym(T)  msiz(*.9) mcol(green*1.)"
local legoptions "ring(0) pos(11) rows(2)"
local titleoptions "ring(2) pos(11) size(*1)"

//  =========================================================================
//  #1. m1: wages on fem age edyears see fox page 267-268

//  #11 wages on fem age edyears

sum wages male age edyears // summarize data
regress wages male age edyears  // run regression
estimates store m1  // store estimates for m1

//  #12 standardized coefficients

//  using transformations of variables

egen Swages = std(wages) 
egen Sage = std(age)
egen Sedyears = std(edyears)
sum Swages wages Sage age

regress wages male age edyears // unstandardized variables
regress Swages male Sage Sedyears // y & x standardized
regress wages male Sage Sedyears // x standardized
regress Swages male age edyears // y standardized

//  using postestimation transformations

qui regress wages male age edyears
listcoef, help

//  #13 plot wages

margins, atmeans at(age=(25(5)65) male=(0 1) edyears=20)

local gnm "m1wages"
marginsplot, ///
    noci ylab(0(10)40, `labgrid') xlab(25(10)65, `labnogrid') ///
    legend(order(2 "Men" 1 "Women") `legoptions') ///
    plot1opts(`plt1options') plot2opts(`plt2options') ///
    plotopts(lwidth(*1)) xtitle("Age") ytitle("Wages") ///
    title("M1: linear with dummy for gender" " ", `titleoptions') ///
    caption("`gnm' `tag'", size(vsmall) pos(5) col(gs10)) ///
    scale(1.1)
graph export `pgm'-`gnm'.$plotfmt, replace

//  #14 gender differences in wages

margins, dydx(male) atmeans at(age=(25(5)65) edyears=20)

local gnm "m1dcmale"
marginsplot, ///
    ylab(0(10)40, `labgrid') xlab(25(10)65, `labnogrid') ///
    plot1opts(`pltDCoptions') plotopts(lwidth(*1)) ///
    xtitle("Age") ytitle("Male Wages - Female Wages") ///
    title("M1: linear with dummy for gender" " ", `titleoptions') ///
    caption("`gnm' `tag'", size(vsmall) pos(5) col(gs10)) ///
    scale(1.1) // saving(temp-olm.gph, replace)
graph export `pgm'-`gnm'.$plotfmt, replace

//  =========================================================================
//  #2+ LRM m2 with age-squared

//  #21 descriptive statistics including age squared

sum wages male c.age##c.age edyears

//  #22 wages + gender + age + age#age + edyears

regress wages male c.age##c.age edyears

//  #23 wages by age and gender

mtable, atmeans at(age=(25(5)65) male=(0 1) edyears=20)

//  #24 predictions with margins 

margins, atmeans at(age=(25(5)65) male=(0 1) edyears=20)

local gnm "m2wages-quick"
marginsplot // quick and dirty plot
graph export `pgm'-`gnm'.$plotfmt, replace

//  refined

local gnm "m2wages"
marginsplot, ///
    noci ylab(0(10)40, `labgrid') xlab(25(10)65, `labnogrid') ///
    legend(order(2 "Men" 1 "Women" ) `legoptions') ///
    plot1opts(`plt1options') plot2opts(`plt2options') ///
    plotopts(lwidth(*1)) xtitle("Age") ytitle("Wages") ///
    title("M2: age-squared with dummy for gender" " ", `titleoptions') ///
    caption("`gnm' `tag'", size(vsmall) pos(5) col(gs10)) ///
    scale(1.1) 
graph export `pgm'-`gnm'.$plotfmt, replace

//  gender differnces

local gnm "m2dcmale"
margins, dydx(male) atmeans at(age=(25(5)65) edyears=20)
marginsplot, ylab(0(10)40, `labgrid') xlab(25(10)65, `labnogrid') ///
    plot1opts(`pltDCoptions') plotopts(lwidth(*1)) ///
    xtitle("Age") ytitle("Male Wages - Female Wages") ///
    title("M2: age-squared with dummy for gender" " ", `titleoptions') ///
    caption("`gnm' `tag'", size(vsmall) pos(5) col(gs10)) ///
    scale(1.1) 
graph export `pgm'-`gnm'.$plotfmt, replace

//  =========================================================================
//  #3+ LRM m3 with with gender interaction 

//  #31 descriptive statistics

sum wages male c.age##c.age edyears

//  #33 factor variables with by gender coefficients

    regress wages ibn.male ibn.male#(c.edyears c.age##c.age), nocon

//  #34 wages by age and gender

local gnm "m3wages"
margins, atmeans at(age=(25(5)65) male=(0 1) edyears=20)
marginsplot, ///
    noci ylab(0(10)40, `labgrid') xlab(25(10)65, `labnogrid') ///
    legend(order(2 "Men" 1 "Women" ) `legoptions') ///
    plot1opts(`plt1options') plot2opts(`plt2options') ///
    plotopts(lwidth(*1)) xtitle("Age") ytitle("Wages") ///
    title("M3: age-squared with gender interaction" " ", `titleoptions') ///
    caption("`gnm' `tag'", size(vsmall) pos(5) col(gs10)) ///
    scale(1.1)
graph export `pgm'-`gnm'.$plotfmt, replace

local gnm "m3dcmale"
margins, dydx(male) atmeans at(age=(25(5)65) edyears=20)
marginsplot, ylab(0(2)10, `labgrid') xlab(25(10)65, `labnogrid') ///
    plot1opts(`pltDCoptions') plotopts(lwidth(*1)) ///
    xtitle("Age") ytitle("Male Wages - Female Wages") ///
    title("M3: age-squared with gender interaction" " ", `titleoptions') ///
    caption("`gnm' `tag'", size(vsmall) pos(5) col(gs10)) ///
    scale(1.1) 
graph export `pgm'-`gnm'.$plotfmt, replace

log close
exit

//  =========================================================================
//  WAGES - using mgen

//  #11 m1: wages on fem age edyears see fox page 267-268

sum wages male age edyears // summarize data
regress wages male age edyears  // run regression
estimates store m1  // store estimates for m1

//  #13 plot wages

mgen, at(male=1 age=(25(5)65) edyears=20) atmeans ///
    /// expression(exp(predict(xb)))
    stub(m1M) predlabel(Men) predname(wages) replace

mgen, at(male=0 age=(25(5)65) edyears=20) atmeans ///
    /// expression(exp(predict(xb))) 
    stub(m1W) predlabel(Women) predname(wages) replace

local gnm "m1wagesMG"
graph twoway ///
    (connected m1Mwages m1Mage, msym(i i) lpat(solid)) ///
    (connected m1Wwages m1Mage, msym(i i) lpat(shortdash))  ///
    , ///
    title("m1: For respondents with 20 years of education", pos(11)) ///
    xtitle(Age) xlab(25(10)65,grid gmax) ///
	ytitle("Wages") ylab(0(10)40, grid gmax gmin) ///
    caption("`gnm' `tag'", size(vsmall) pos(5) col(gs10))
graph export `pgm'-`gnm'.$plotfmt, replace

//  #2+ LRM m2 with age-squared ===============================================

//  #21 descriptive statistics including age squared

sum wages wages male c.age##c.age edyears

//  #22 wages + gender + age + age#age + edyears

regress wages male c.age##c.age edyears

//  #23 wages by age and gender

mgen, at(male=1 age=(25(5)65) edyears=20) atmeans predlabel(Men) ///
    stub(m2M) predname(wages)

mgen, at(male=0 age=(25(5)65) edyears=20) atmeans predlabel(Women) ///
    stub(m2W) predname(wages)

//  #24 plot wages by age

local gnm "m2wagesMG"
graph twoway ///
    (connected m2Mwages m2Mage, msym(i i) lpat(solid)) ///
    (connected m2Wwages m2Mage, msym(i i) lpat(shortdash)) ///
    , ///
    title("m2: For respondents with 20 years of education", pos(11)) ///
    xtitle(Age) xlab(25(10)65, grid gmax) ///
	ytitle("Wages") ylab(0(10)40, grid gmax gmin) ///
    caption("`gnm' `tag'", size(vsmall) pos(5) col(gs10))
graph export `pgm'-`gnm'.$plotfmt, replace

//  #3+ LRM m3 with with gender interaction ===================================

//  #31 descriptive statistics

sum wages wages male c.age##c.age edyears

//  #33 factor variables with by gender coefficients

regress wages ibn.male ibn.male#(c.edyears c.age##c.age), nocon

//  #34 wages by age and gender

mgen, at(age=(25(5)65) edyears=20 male=0) atmeans stub(m3F) ///
    predname(wages) predlabel(Women)

mgen, at(age=(25(5)65) edyears=20 male=1) atmeans stub(m3M) ///
    predname(wages) predlabel(Men)

*mgen, dydx(male) at(age=(25(5)65) edyears=20) atmeans stub(m3DC) ///
*    predlabel(Difference)

//  #35 plot wages by age

local gnm "m3wagesMG"
graph twoway ///
    (connected m3Mwages m3Mage, msym(i i) lpat(solid)) ///
    (connected m3Fwages m3Fage, msym(i i) lpat(shortdash)) ///
    , ///
    title("m3: At 20 years of education", pos(11)) ///
    xtitle(Age) xlab(25(10)65,grid gmax) ///
	ytitle("Wages") ylab(0(10)40, grid gmax gmin) ///
    caption("`gnm' `tag'", size(vsmall) pos(5) col(gs10))
graph export `pgm'-`gnm'.$plotfmt, replace
